You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@openoffice.apache.org by st...@apache.org on 2013/02/01 09:46:35 UTC

svn commit: r1441343 [35/35] - in /openoffice/branches/ia2: ./ ext_libraries/apr-util/ ext_libraries/apr/ ext_sources/ extras/l10n/source/ast/ extras/l10n/source/da/ extras/l10n/source/eu/ extras/l10n/source/gd/ extras/l10n/source/ko/ extras/l10n/sourc...

Modified: openoffice/branches/ia2/main/winaccessibility/source/UAccCOM/AccAction.h
URL: http://svn.apache.org/viewvc/openoffice/branches/ia2/main/winaccessibility/source/UAccCOM/AccAction.h?rev=1441343&r1=1441342&r2=1441343&view=diff
==============================================================================
--- openoffice/branches/ia2/main/winaccessibility/source/UAccCOM/AccAction.h (original)
+++ openoffice/branches/ia2/main/winaccessibility/source/UAccCOM/AccAction.h Fri Feb  1 08:46:00 2013
@@ -85,7 +85,7 @@ public:
     // Gets description of specified action.
     STDMETHOD(get_description)(long actionIndex,BSTR __RPC_FAR *description);
 
-    // added by qiuhd, 2006/06/28, for driver 07/11
+    // added , 2006/06/28, for driver 07/11
     // get the action name
     STDMETHOD(get_name)( long actionIndex, BSTR __RPC_FAR *name);
 

Modified: openoffice/branches/ia2/main/winaccessibility/source/UAccCOM/AccActionBase.h
URL: http://svn.apache.org/viewvc/openoffice/branches/ia2/main/winaccessibility/source/UAccCOM/AccActionBase.h?rev=1441343&r1=1441342&r2=1441343&view=diff
==============================================================================
--- openoffice/branches/ia2/main/winaccessibility/source/UAccCOM/AccActionBase.h (original)
+++ openoffice/branches/ia2/main/winaccessibility/source/UAccCOM/AccActionBase.h Fri Feb  1 08:46:00 2013
@@ -62,7 +62,7 @@ public:
     // Gets description of specified action.
     STDMETHOD(get_description)(long actionIndex,BSTR __RPC_FAR *description);
 
-    // added by qiuhd, 2006/06/28, for driver 07/11
+    // added , 2006/06/28, for driver 07/11
     // get the action name
     STDMETHOD(get_name)( long actionIndex, BSTR __RPC_FAR *name);
 

Modified: openoffice/branches/ia2/main/winaccessibility/source/UAccCOM/UAccCOM.def
URL: http://svn.apache.org/viewvc/openoffice/branches/ia2/main/winaccessibility/source/UAccCOM/UAccCOM.def?rev=1441343&r1=1441342&r2=1441343&view=diff
==============================================================================
--- openoffice/branches/ia2/main/winaccessibility/source/UAccCOM/UAccCOM.def (original)
+++ openoffice/branches/ia2/main/winaccessibility/source/UAccCOM/UAccCOM.def Fri Feb  1 08:46:00 2013
@@ -29,7 +29,7 @@
 LIBRARY      "UAccCOM.DLL"
 
 EXPORTS
-	DllCanUnloadNow     PRIVATE
-	DllGetClassObject   PRIVATE
-	DllRegisterServer   PRIVATE
-	DllUnregisterServer	PRIVATE
+	DllCanUnloadNow     @1 PRIVATE
+	DllGetClassObject   @2 PRIVATE
+	DllRegisterServer   @3 PRIVATE
+	DllUnregisterServer	@4 PRIVATE

Modified: openoffice/branches/ia2/main/winaccessibility/source/UAccCOM/makefile.mk
URL: http://svn.apache.org/viewvc/openoffice/branches/ia2/main/winaccessibility/source/UAccCOM/makefile.mk?rev=1441343&r1=1441342&r2=1441343&view=diff
==============================================================================
--- openoffice/branches/ia2/main/winaccessibility/source/UAccCOM/makefile.mk (original)
+++ openoffice/branches/ia2/main/winaccessibility/source/UAccCOM/makefile.mk Fri Feb  1 08:46:00 2013
@@ -135,7 +135,7 @@ LINKFLAGS += /delayload:sal3.dll \
     
 SHL1OBJS=$(SLOFILES)
 SHL1DEF=$(TARGET).def 
-SHL1RES=$(RES)$/$(TARGET).res 
+SHL1RES=$(RES)/$(TARGET).res 
 
 DEF1NAME= $(TARGET)
 #DEF1EXPORTFILE=	exports.dxp

Modified: openoffice/branches/ia2/main/winaccessibility/source/service/makefile.mk
URL: http://svn.apache.org/viewvc/openoffice/branches/ia2/main/winaccessibility/source/service/makefile.mk?rev=1441343&r1=1441342&r2=1441343&view=diff
==============================================================================
--- openoffice/branches/ia2/main/winaccessibility/source/service/makefile.mk (original)
+++ openoffice/branches/ia2/main/winaccessibility/source/service/makefile.mk Fri Feb  1 08:46:00 2013
@@ -118,7 +118,7 @@ my_platform = .windows
 $(MISC)/winaccessibility.component .ERRREMOVE : \
         $(SOLARENV)/bin/createcomponent.xslt winaccessibility.component
     $(XSLTPROC) --nonet --stringparam uri \
-        '$(COMPONENTPREFIX_BASIS_NATIVE)$(SHL4TARGETN:f)' -o $@ \
+        '$(COMPONENTPREFIX_BASIS_NATIVE)$(SHL1TARGETN:f)' -o $@ \
         $(SOLARENV)/bin/createcomponent.xslt winaccessibility.component
 
 

Modified: openoffice/branches/ia2/main/winaccessibility/source/service/msaaservice_impl.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/ia2/main/winaccessibility/source/service/msaaservice_impl.cxx?rev=1441343&r1=1441342&r2=1441343&view=diff
==============================================================================
--- openoffice/branches/ia2/main/winaccessibility/source/service/msaaservice_impl.cxx (original)
+++ openoffice/branches/ia2/main/winaccessibility/source/service/msaaservice_impl.cxx Fri Feb  1 08:46:00 2013
@@ -286,14 +286,6 @@ extern "C"
     {
         *ppEnvTypeName = CPPU_CURRENT_LANGUAGE_BINDING_NAME;
     }
-/*    
-    sal_Bool SAL_CALL component_writeInfo(
-        lang::XMultiServiceFactory * xMgr, registry::XRegistryKey * xRegistry )
-    {
-        return ::cppu::component_writeInfoHelper(
-                   xMgr, xRegistry, ::my_sc_impl::s_component_entries );
-    }
-*/ 
     void * SAL_CALL component_getFactory(
         sal_Char const * implName, lang::XMultiServiceFactory * xMgr,
         registry::XRegistryKey * xRegistry )

Modified: openoffice/branches/ia2/main/wizards/com/sun/star/wizards/document/DatabaseControl.java
URL: http://svn.apache.org/viewvc/openoffice/branches/ia2/main/wizards/com/sun/star/wizards/document/DatabaseControl.java?rev=1441343&r1=1441342&r2=1441343&view=diff
==============================================================================
--- openoffice/branches/ia2/main/wizards/com/sun/star/wizards/document/DatabaseControl.java (original)
+++ openoffice/branches/ia2/main/wizards/com/sun/star/wizards/document/DatabaseControl.java Fri Feb  1 08:46:00 2013
@@ -250,7 +250,7 @@ public class DatabaseControl extends Con
             // }
             else if (getControlType() == FormHandler.SOIMAGECONTROL)
             {
-                xPropertySet.setPropertyValue("ScaleMode", com.sun.star.awt.ImageScaleMode.Isotropic);
+                xPropertySet.setPropertyValue("ScaleMode", com.sun.star.awt.ImageScaleMode.ISOTROPIC);
             }
         }
         catch (Exception e)

Modified: openoffice/branches/ia2/main/wizards/com/sun/star/wizards/reportbuilder/layout/ReportBuilderLayouter.java
URL: http://svn.apache.org/viewvc/openoffice/branches/ia2/main/wizards/com/sun/star/wizards/reportbuilder/layout/ReportBuilderLayouter.java?rev=1441343&r1=1441342&r2=1441343&view=diff
==============================================================================
--- openoffice/branches/ia2/main/wizards/com/sun/star/wizards/reportbuilder/layout/ReportBuilderLayouter.java (original)
+++ openoffice/branches/ia2/main/wizards/com/sun/star/wizards/reportbuilder/layout/ReportBuilderLayouter.java Fri Feb  1 08:46:00 2013
@@ -801,7 +801,7 @@ abstract public class ReportBuilderLayou
                         {
                             // xImageControl.setScaleImage(true);
 
-                            xImageControl.setScaleMode(com.sun.star.awt.ImageScaleMode.Isotropic);
+                            xImageControl.setScaleMode(com.sun.star.awt.ImageScaleMode.ISOTROPIC);
                         }
                     }
                     else

Modified: openoffice/branches/ia2/main/xmerge/source/activesync/XMergeFilter.cpp
URL: http://svn.apache.org/viewvc/openoffice/branches/ia2/main/xmerge/source/activesync/XMergeFilter.cpp?rev=1441343&r1=1441342&r2=1441343&view=diff
==============================================================================
--- openoffice/branches/ia2/main/xmerge/source/activesync/XMergeFilter.cpp (original)
+++ openoffice/branches/ia2/main/xmerge/source/activesync/XMergeFilter.cpp Fri Feb  1 08:46:00 2013
@@ -38,8 +38,8 @@
                       
 const LPTSTR CXMergeFilter::m_pszPSWExportCLSID		= _T("{BDD611C3-7BAB-460F-8711-5B9AC9EF6020}");
 const LPTSTR CXMergeFilter::m_pszPSWExportExt		= _T("sxw");
-const LPTSTR CXMergeFilter::m_pszPSWExportDesc		= _T("OpenOffice.org Writer XML Document");
-const LPTSTR CXMergeFilter::m_pszPSWExportShortDesc	= _T("OpenOffice.org Writer");
+const LPTSTR CXMergeFilter::m_pszPSWExportDesc		= _T("OpenOffice.org XML Writer Document");
+const LPTSTR CXMergeFilter::m_pszPSWExportShortDesc	= _T("OpenOffice.org XML Writer");
 
 const LPTSTR CXMergeFilter::m_pszPSWImportCLSID		= _T("{CB43F086-838D-4FA4-B5F6-3406B9A57439}");
 const LPTSTR CXMergeFilter::m_pszPSWImportExt		= _T("psw");
@@ -48,8 +48,8 @@ const LPTSTR CXMergeFilter::m_pszPSWImpo
 
 const LPTSTR CXMergeFilter::m_pszPXLExportCLSID		= _T("{C6AB3E74-9F4F-4370-8120-A8A6FABB7A7C}");
 const LPTSTR CXMergeFilter::m_pszPXLExportExt		= _T("sxc");
-const LPTSTR CXMergeFilter::m_pszPXLExportDesc		= _T("OpenOffice.org Calc XML Document");
-const LPTSTR CXMergeFilter::m_pszPXLExportShortDesc	= _T("OpenOffice.org Calc");
+const LPTSTR CXMergeFilter::m_pszPXLExportDesc		= _T("OpenOffice.org XML Calc Document");
+const LPTSTR CXMergeFilter::m_pszPXLExportShortDesc	= _T("OpenOffice.org XML Calc");
 
 const LPTSTR CXMergeFilter::m_pszPXLImportCLSID		= _T("{43887C67-4D5D-4127-BAAC-87A288494C7C}");
 const LPTSTR CXMergeFilter::m_pszPXLImportExt		= _T("pxl");
@@ -237,7 +237,7 @@ STDMETHODIMP CXMergeFilter::NextConvertF
 		}
 	}
 
-	// Get the StarOffice/OpenOffice class directory
+	// Get the Apache OpenOffice class directory
 	if (m_szClasspath == NULL)
 	{
 		m_szClasspath = GetXMergeClassPath();

Modified: openoffice/branches/ia2/main/xmerge/source/aportisdoc/converter.xml
URL: http://svn.apache.org/viewvc/openoffice/branches/ia2/main/xmerge/source/aportisdoc/converter.xml?rev=1441343&r1=1441342&r2=1441343&view=diff
==============================================================================
--- openoffice/branches/ia2/main/xmerge/source/aportisdoc/converter.xml (original)
+++ openoffice/branches/ia2/main/xmerge/source/aportisdoc/converter.xml Fri Feb  1 08:46:00 2013
@@ -29,7 +29,7 @@
         <converter-description>
             StarWriter XML to/from AportisDoc conversion
         </converter-description>
-        <converter-vendor>OpenOffice.org</converter-vendor>
+        <converter-vendor>Apache OpenOffice</converter-vendor>
         <converter-class-impl>
             org.openoffice.xmerge.converter.xml.sxw.aportisdoc.PluginFactoryImpl
         </converter-class-impl>

Modified: openoffice/branches/ia2/main/xmerge/source/aportisdoc/java/org/openoffice/xmerge/converter/xml/sxw/aportisdoc/DocDecoder.java
URL: http://svn.apache.org/viewvc/openoffice/branches/ia2/main/xmerge/source/aportisdoc/java/org/openoffice/xmerge/converter/xml/sxw/aportisdoc/DocDecoder.java?rev=1441343&r1=1441342&r2=1441343&view=diff
==============================================================================
--- openoffice/branches/ia2/main/xmerge/source/aportisdoc/java/org/openoffice/xmerge/converter/xml/sxw/aportisdoc/DocDecoder.java (original)
+++ openoffice/branches/ia2/main/xmerge/source/aportisdoc/java/org/openoffice/xmerge/converter/xml/sxw/aportisdoc/DocDecoder.java Fri Feb  1 08:46:00 2013
@@ -32,8 +32,7 @@ import org.openoffice.xmerge.util.Resour
 import org.openoffice.xmerge.util.Debug;
 
 /**
- *  This class is used by {@link
- *  org.openoffice.xmerge.converter.xml.sxw.DocumentDeserializerImpl}
+ *  This class is used by {@link DocumentDeserializerImpl}
  *  to decode the AportisDoc format.  It currently decodes
  *  the text content into a single <code>String</code> object.
  *
@@ -61,7 +60,7 @@ final class DocDecoder implements DocCon
      *  Decode the text records into a single <code>String</code>
      *  of text content.
      *
-     *  @param  Record  <code>Record</code> array holding AportisDoc
+     *  @param  recs  <code>Record</code> array holding AportisDoc
      *                  contents.
      *
      *  @throws  IOException  If any I/O error occurs.
@@ -119,7 +118,7 @@ final class DocDecoder implements DocCon
      *  with the encoding of that PDB and throw
      *  <code>IOException</code>.</p>
      *
-     *  @param  bytes           Compressed <code>byte</code> array.
+     *  @param  cBytes           Compressed <code>byte</code> array.
      *  @param  textRecordSize  Size of uncompressed
      *                          <code>byte</code> array.
      *

Modified: openoffice/branches/ia2/main/xmerge/source/aportisdoc/java/org/openoffice/xmerge/converter/xml/sxw/aportisdoc/DocEncoder.java
URL: http://svn.apache.org/viewvc/openoffice/branches/ia2/main/xmerge/source/aportisdoc/java/org/openoffice/xmerge/converter/xml/sxw/aportisdoc/DocEncoder.java?rev=1441343&r1=1441342&r2=1441343&view=diff
==============================================================================
--- openoffice/branches/ia2/main/xmerge/source/aportisdoc/java/org/openoffice/xmerge/converter/xml/sxw/aportisdoc/DocEncoder.java (original)
+++ openoffice/branches/ia2/main/xmerge/source/aportisdoc/java/org/openoffice/xmerge/converter/xml/sxw/aportisdoc/DocEncoder.java Fri Feb  1 08:46:00 2013
@@ -32,9 +32,7 @@ import java.util.ArrayList;
 import org.openoffice.xmerge.converter.palm.Record;
 
 /**
- *  This class is used by {@link
- *  org.openoffice.xmerge.converter.xml.sxw.DocumentSerializerImpl
- *  DocumentSerializerImpl} to encode the AportisDoc format.
+ *  This class is used by {@link DocumentSerializerImpl} to encode the AportisDoc format.
  *  It does not deal with any XML tags.  It only knows how to encode
  *  from <code>String</code>.
  *

Modified: openoffice/branches/ia2/main/xmerge/source/aportisdoc/java/org/openoffice/xmerge/converter/xml/sxw/aportisdoc/package.html
URL: http://svn.apache.org/viewvc/openoffice/branches/ia2/main/xmerge/source/aportisdoc/java/org/openoffice/xmerge/converter/xml/sxw/aportisdoc/package.html?rev=1441343&r1=1441342&r2=1441343&view=diff
==============================================================================
--- openoffice/branches/ia2/main/xmerge/source/aportisdoc/java/org/openoffice/xmerge/converter/xml/sxw/aportisdoc/package.html (original)
+++ openoffice/branches/ia2/main/xmerge/source/aportisdoc/java/org/openoffice/xmerge/converter/xml/sxw/aportisdoc/package.html Fri Feb  1 08:46:00 2013
@@ -163,7 +163,7 @@ then passed back to the client via the <
     <tt>&lt;text:change*&gt;</tt> [Not implemented yet]</p>
 
     <p>Change tracking elements are not supported yet on the current
-    OpenOffice XML filters, will have to watch out on this.  The text
+    OpenOffice.org XML filters, will have to watch out on this.  The text
     within these elements have to be interpreted properly during the
     conversion process.</p>
 </li>

Modified: openoffice/branches/ia2/main/xmerge/source/htmlsoff/converter.xml
URL: http://svn.apache.org/viewvc/openoffice/branches/ia2/main/xmerge/source/htmlsoff/converter.xml?rev=1441343&r1=1441342&r2=1441343&view=diff
==============================================================================
--- openoffice/branches/ia2/main/xmerge/source/htmlsoff/converter.xml (original)
+++ openoffice/branches/ia2/main/xmerge/source/htmlsoff/converter.xml Fri Feb  1 08:46:00 2013
@@ -30,7 +30,7 @@
         <converter-description>
 	    Converter which performs xslt transformations
         </converter-description>
-        <converter-vendor>OpenOffice.org</converter-vendor>
+        <converter-vendor>Apache OpenOffice</converter-vendor>
         <converter-class-impl>
 	          org.openoffice.xmerge.converter.xml.xslt.PluginFactoryImpl
 	</converter-class-impl>

Modified: openoffice/branches/ia2/main/xmerge/source/htmlsoff/package.html
URL: http://svn.apache.org/viewvc/openoffice/branches/ia2/main/xmerge/source/htmlsoff/package.html?rev=1441343&r1=1441342&r2=1441343&view=diff
==============================================================================
--- openoffice/branches/ia2/main/xmerge/source/htmlsoff/package.html (original)
+++ openoffice/branches/ia2/main/xmerge/source/htmlsoff/package.html Fri Feb  1 08:46:00 2013
@@ -38,8 +38,8 @@ Transformation</B></FONT></FONT></P>
 of one or more XSLT style sheets, which are used in the
 DocumentSerializer and DocumentDeserializer, to perform the actual
 translations. The location of these stylesheets is extracted from the {@link org.openoffice.xmerge.util.registry.ConverterInfo ConverterInfo} data structure, and are specified using the optional converter-xslt-serialize and converter-xsltdeserialize tags in a plugins converter.xml file. Please refer to the SDK document for more information about how to implement a Plugin Configuration XML File for a specific plugin.
-A sample OpenOffice to Html stylesheet and Html to
-Openffice stylesheet, has been provided as a sample implementation.
+A sample OpenOffice.org XML to Html stylesheet and Html to
+Openffice.org XML stylesheet, has been provided as a sample implementation.
 The converter also makes use of an XsltPlugin.properties file, which may be edited by the user to provide MIME-TYPE to file extension mappings. This file is used by the {@link org.openoffice.xmerge.converter.xml.xslt.PluginFactoryImpl getDeviceFileExtension} method.
 </p>
 

Modified: openoffice/branches/ia2/main/xmerge/source/minicalc/converter.xml
URL: http://svn.apache.org/viewvc/openoffice/branches/ia2/main/xmerge/source/minicalc/converter.xml?rev=1441343&r1=1441342&r2=1441343&view=diff
==============================================================================
--- openoffice/branches/ia2/main/xmerge/source/minicalc/converter.xml (original)
+++ openoffice/branches/ia2/main/xmerge/source/minicalc/converter.xml Fri Feb  1 08:46:00 2013
@@ -29,7 +29,7 @@
         <converter-description>
             StarCalc XML to/from Minicalc 6.4 conversion
         </converter-description>
-        <converter-vendor>OpenOffice.org</converter-vendor>
+        <converter-vendor>Apache OpenOffice</converter-vendor>
         <converter-class-impl>
             org.openoffice.xmerge.converter.xml.sxc.minicalc.PluginFactoryImpl
         </converter-class-impl>

Modified: openoffice/branches/ia2/main/xmerge/source/pexcel/converter.xml
URL: http://svn.apache.org/viewvc/openoffice/branches/ia2/main/xmerge/source/pexcel/converter.xml?rev=1441343&r1=1441342&r2=1441343&view=diff
==============================================================================
--- openoffice/branches/ia2/main/xmerge/source/pexcel/converter.xml (original)
+++ openoffice/branches/ia2/main/xmerge/source/pexcel/converter.xml Fri Feb  1 08:46:00 2013
@@ -29,7 +29,7 @@
         <converter-description>
             StarCalc XML to/from Pocket Excel 2.0 conversion
         </converter-description>
-        <converter-vendor>OpenOffice.org</converter-vendor>
+        <converter-vendor>Apache OpenOffice</converter-vendor>
         <converter-class-impl>
             org.openoffice.xmerge.converter.xml.sxc.pexcel.PluginFactoryImpl
         </converter-class-impl>

Modified: openoffice/branches/ia2/main/xmerge/source/pexcel/java/org/openoffice/xmerge/converter/xml/sxc/pexcel/PocketExcelDecoder.java
URL: http://svn.apache.org/viewvc/openoffice/branches/ia2/main/xmerge/source/pexcel/java/org/openoffice/xmerge/converter/xml/sxc/pexcel/PocketExcelDecoder.java?rev=1441343&r1=1441342&r2=1441343&view=diff
==============================================================================
--- openoffice/branches/ia2/main/xmerge/source/pexcel/java/org/openoffice/xmerge/converter/xml/sxc/pexcel/PocketExcelDecoder.java (original)
+++ openoffice/branches/ia2/main/xmerge/source/pexcel/java/org/openoffice/xmerge/converter/xml/sxc/pexcel/PocketExcelDecoder.java Fri Feb  1 08:46:00 2013
@@ -39,8 +39,7 @@ import org.openoffice.xmerge.converter.x
 import org.openoffice.xmerge.converter.xml.sxc.pexcel.records.*;
 
 /**
- *  This class is used by {@link
- *  org.openoffice.xmerge.converter.xml.sxc.SxcDocumentDeserializerImpl}
+ *  This class is used by {@link SxcDocumentDeserializerImpl}
  *  SxcDocumentDeserializerImpl} to decode the Pocket Excel format.
  *
  *  @author   Paul Rank
@@ -78,7 +77,7 @@ final class PocketExcelDecoder extends S
      *  converts it into a PocketWord WorkSheet.  The WorkSheet is then
      *  added to the WorkBook.
      *
-     *  @param  InputStream An <code>ConvertData</code> containing a
+     *  @param  cd An <code>ConvertData</code> containing a
      *                      Pocket Excel WorkSheet.
      *
      *  @throws  IOException  If any I/O error occurs.

Modified: openoffice/branches/ia2/main/xmerge/source/pexcel/java/org/openoffice/xmerge/converter/xml/sxc/pexcel/PocketExcelEncoder.java
URL: http://svn.apache.org/viewvc/openoffice/branches/ia2/main/xmerge/source/pexcel/java/org/openoffice/xmerge/converter/xml/sxc/pexcel/PocketExcelEncoder.java?rev=1441343&r1=1441342&r2=1441343&view=diff
==============================================================================
--- openoffice/branches/ia2/main/xmerge/source/pexcel/java/org/openoffice/xmerge/converter/xml/sxc/pexcel/PocketExcelEncoder.java (original)
+++ openoffice/branches/ia2/main/xmerge/source/pexcel/java/org/openoffice/xmerge/converter/xml/sxc/pexcel/PocketExcelEncoder.java Fri Feb  1 08:46:00 2013
@@ -35,9 +35,7 @@ import org.openoffice.xmerge.converter.x
 import org.openoffice.xmerge.converter.xml.sxc.pexcel.records.Workbook;
 
 /**
- *  This class is used by {@link
- *  org.openoffice.xmerge.converter.xml.sxc.SxcDocumentSerializerImpl
- * SxcDocumentSerializerImpl} to encode the Pocket Excel format.
+ *  This class is used by {@link SxcDocumentSerializerImpl} to encode the Pocket Excel format.
  *
  *  @author  Martin Maher 
  */

Modified: openoffice/branches/ia2/main/xmerge/source/pocketword/converter.xml
URL: http://svn.apache.org/viewvc/openoffice/branches/ia2/main/xmerge/source/pocketword/converter.xml?rev=1441343&r1=1441342&r2=1441343&view=diff
==============================================================================
--- openoffice/branches/ia2/main/xmerge/source/pocketword/converter.xml (original)
+++ openoffice/branches/ia2/main/xmerge/source/pocketword/converter.xml Fri Feb  1 08:46:00 2013
@@ -30,10 +30,10 @@
             Pocket Word
         </converter-display-name>
         <converter-description>
-            OpenOffice Writer XML to/from Pocket Word conversion.
+            OpenOffice.org XML Writer to/from Pocket Word conversion.
         </converter-description>
         <converter-vendor>
-            OpenOffice.org
+            Apache OpenOffice
         </converter-vendor>
         <converter-class-impl>
             org.openoffice.xmerge.converter.xml.sxw.pocketword.PluginFactoryImpl

Modified: openoffice/branches/ia2/main/xmerge/source/pocketword/java/org/openoffice/xmerge/converter/xml/sxw/pocketword/DocumentDeserializerImpl.java
URL: http://svn.apache.org/viewvc/openoffice/branches/ia2/main/xmerge/source/pocketword/java/org/openoffice/xmerge/converter/xml/sxw/pocketword/DocumentDeserializerImpl.java?rev=1441343&r1=1441342&r2=1441343&view=diff
==============================================================================
--- openoffice/branches/ia2/main/xmerge/source/pocketword/java/org/openoffice/xmerge/converter/xml/sxw/pocketword/DocumentSerializerImpl.java (original)
+++ openoffice/branches/ia2/main/xmerge/source/pocketword/java/org/openoffice/xmerge/converter/xml/sxw/pocketword/DocumentSerializerImpl.java Fri Feb  1 08:46:00 2013
@@ -48,7 +48,7 @@ import java.io.IOException;
  * org.openoffice.xmerge.converter.xml.sxw.pocketword.PluginFactoryImpl
  * PluginFactoryImpl}.</p>
  *
- * <p>This converts an OpenOffice Writer XML files to a Pocket Word file<.</p>
+ * <p>This converts an OpenOffice.org XML Writer files to a Pocket Word file<.</p>
  *
  * @author      Mark Murnane
  * @version 1.1

Modified: openoffice/branches/ia2/main/xmerge/source/pocketword/java/org/openoffice/xmerge/converter/xml/sxw/pocketword/ParagraphTextSegment.java
URL: http://svn.apache.org/viewvc/openoffice/branches/ia2/main/xmerge/source/pocketword/java/org/openoffice/xmerge/converter/xml/sxw/pocketword/ParagraphTextSegment.java?rev=1441343&r1=1441342&r2=1441343&view=diff
==============================================================================
--- openoffice/branches/ia2/main/xmerge/source/pocketword/java/org/openoffice/xmerge/converter/xml/sxw/pocketword/ParagraphTextSegment.java (original)
+++ openoffice/branches/ia2/main/xmerge/source/pocketword/java/org/openoffice/xmerge/converter/xml/sxw/pocketword/ParagraphTextSegment.java Fri Feb  1 08:46:00 2013
@@ -80,7 +80,7 @@ class ParagraphTextSegment implements Po
     /**
      * <p>Sets the style for this segment.</p>
      *
-     * @param   data    The style describing this segment.
+     * @param   style    The style describing this segment.
      */
     public void setStyle (TextStyle style) {
         pStyle = style;

Modified: openoffice/branches/ia2/main/xmerge/source/pocketword/java/org/openoffice/xmerge/converter/xml/sxw/pocketword/PluginFactoryImpl.java
URL: http://svn.apache.org/viewvc/openoffice/branches/ia2/main/xmerge/source/pocketword/java/org/openoffice/xmerge/converter/xml/sxw/pocketword/PluginFactoryImpl.java?rev=1441343&r1=1441342&r2=1441343&view=diff
==============================================================================
--- openoffice/branches/ia2/main/xmerge/source/pocketword/java/org/openoffice/xmerge/converter/xml/sxw/pocketword/PluginFactoryImpl.java (original)
+++ openoffice/branches/ia2/main/xmerge/source/pocketword/java/org/openoffice/xmerge/converter/xml/sxw/pocketword/PluginFactoryImpl.java Fri Feb  1 08:46:00 2013
@@ -69,7 +69,7 @@ public final class PluginFactoryImpl ext
 
     /**
      *  <p>The <code>DocumentSerializer</code> is used to convert 
-     *  from the OpenOffice Writer <code>Document</code> format 
+     *  from the OpenOffice.org XML Writer <code>Document</code> format 
      *  to the Pocket Word <code>Document</code> format.</p>
      *
      *  <p>The <code>ConvertData</code> object is passed along to the
@@ -92,7 +92,7 @@ public final class PluginFactoryImpl ext
     /**
      *  The <code>DocumentDeserializer</code> is used to convert
      *  from the Pocket Word <code>Document</code> format to
-     *  the OpenOffice Writer <code>Document</code> format.</p>
+     *  the OpenOffice.org XML Writer <code>Document</code> format.</p>
      *
      *  The <code>ConvertData</code> object is passed along to the
      *  created <code>DocumentDeserializer</code> via its constructor.

Modified: openoffice/branches/ia2/main/xmerge/source/pocketword/java/org/openoffice/xmerge/converter/xml/sxw/pocketword/PocketWordDocument.java
URL: http://svn.apache.org/viewvc/openoffice/branches/ia2/main/xmerge/source/pocketword/java/org/openoffice/xmerge/converter/xml/sxw/pocketword/PocketWordDocument.java?rev=1441343&r1=1441342&r2=1441343&view=diff
==============================================================================
--- openoffice/branches/ia2/main/xmerge/source/pocketword/java/org/openoffice/xmerge/converter/xml/sxw/pocketword/PocketWordDocument.java (original)
+++ openoffice/branches/ia2/main/xmerge/source/pocketword/java/org/openoffice/xmerge/converter/xml/sxw/pocketword/PocketWordDocument.java Fri Feb  1 08:46:00 2013
@@ -41,7 +41,7 @@ import java.util.Vector;
  * <p>Class representing a Pocket Word Document.</p>
  *
  * <p><code>PocketWordDocument</code> is used to create new Pocket Word documents
- *    and to read existing data to allow for conversion to OpenOffice Writer 
+ *    and to read existing data to allow for conversion to OpenOffice.org XML Writer 
  *    format.</p>
  *
  * @author  Mark Murnane

Modified: openoffice/branches/ia2/main/xmerge/source/wordsmith/converter.xml
URL: http://svn.apache.org/viewvc/openoffice/branches/ia2/main/xmerge/source/wordsmith/converter.xml?rev=1441343&r1=1441342&r2=1441343&view=diff
==============================================================================
--- openoffice/branches/ia2/main/xmerge/source/wordsmith/converter.xml (original)
+++ openoffice/branches/ia2/main/xmerge/source/wordsmith/converter.xml Fri Feb  1 08:46:00 2013
@@ -27,7 +27,7 @@
         <converter-description>
             StarWriter XML to/from WordSmith conversion
         </converter-description>
-        <converter-vendor>OpenOffice.org</converter-vendor>
+        <converter-vendor>Apache OpenOffice</converter-vendor>
         <converter-class-impl>
             org.openoffice.xmerge.converter.xml.sxw.wordsmith.PluginFactoryImpl
         </converter-class-impl>

Modified: openoffice/branches/ia2/main/xmerge/source/wordsmith/java/org/openoffice/xmerge/converter/xml/sxw/wordsmith/DocumentDeserializerImpl.java
URL: http://svn.apache.org/viewvc/openoffice/branches/ia2/main/xmerge/source/wordsmith/java/org/openoffice/xmerge/converter/xml/sxw/wordsmith/DocumentDeserializerImpl.java?rev=1441343&r1=1441342&r2=1441343&view=diff
==============================================================================
--- openoffice/branches/ia2/main/xmerge/source/wordsmith/java/org/openoffice/xmerge/converter/xml/sxw/wordsmith/DocumentDeserializerImpl.java (original)
+++ openoffice/branches/ia2/main/xmerge/source/wordsmith/java/org/openoffice/xmerge/converter/xml/sxw/wordsmith/DocumentDeserializerImpl.java Fri Feb  1 08:46:00 2013
@@ -287,7 +287,7 @@ implements DOCConstants, OfficeConstants
      *  <code>SXWDocument</code>.
      *
      *  @param  docName  <code>Document</code> name
-     *  @param  str      Text content of WordSmith format
+     *  @param  data      Text content of WordSmith format
      *
      *  @return  Resulting <code>SXWDocument</code> object.
      *

Modified: openoffice/branches/ia2/main/xmerge/source/wordsmith/java/org/openoffice/xmerge/converter/xml/sxw/wordsmith/DocumentSerializerImpl.java
URL: http://svn.apache.org/viewvc/openoffice/branches/ia2/main/xmerge/source/wordsmith/java/org/openoffice/xmerge/converter/xml/sxw/wordsmith/DocumentSerializerImpl.java?rev=1441343&r1=1441342&r2=1441343&view=diff
==============================================================================
--- openoffice/branches/ia2/main/xmerge/source/wordsmith/java/org/openoffice/xmerge/converter/xml/sxw/wordsmith/DocumentSerializerImpl.java (original)
+++ openoffice/branches/ia2/main/xmerge/source/wordsmith/java/org/openoffice/xmerge/converter/xml/sxw/wordsmith/DocumentSerializerImpl.java Fri Feb  1 08:46:00 2013
@@ -462,7 +462,7 @@ implements OfficeConstants, DocumentSeri
      *  <i>text:h</i>, <i>text:unordered-list</i> and
      *  <i>text:ordered-list</i>.
      *
-     *  @param  Node  <code>Node</code> to traverse.
+     *  @param  node  <code>Node</code> to traverse.
      *
      *  @throws  IOException  If any I/O error occurs.
      */

Modified: openoffice/branches/ia2/main/xmerge/source/wordsmith/java/org/openoffice/xmerge/converter/xml/sxw/wordsmith/PluginFactoryImpl.java
URL: http://svn.apache.org/viewvc/openoffice/branches/ia2/main/xmerge/source/wordsmith/java/org/openoffice/xmerge/converter/xml/sxw/wordsmith/PluginFactoryImpl.java?rev=1441343&r1=1441342&r2=1441343&view=diff
==============================================================================
--- openoffice/branches/ia2/main/xmerge/source/wordsmith/java/org/openoffice/xmerge/converter/xml/sxw/wordsmith/PluginFactoryImpl.java (original)
+++ openoffice/branches/ia2/main/xmerge/source/wordsmith/java/org/openoffice/xmerge/converter/xml/sxw/wordsmith/PluginFactoryImpl.java Fri Feb  1 08:46:00 2013
@@ -131,8 +131,6 @@ public final class PluginFactoryImpl ext
      *  which is an implementation of the <code>DocumentMerger</code>
      *  interface.
      *
-     *  @param  doc  <code>Document</code> to merge.
-     *
      *  @return  A Device Document object
      */	
     public Document createDeviceDocument(String name, InputStream is)

Modified: openoffice/branches/ia2/main/xmerge/source/wordsmith/java/org/openoffice/xmerge/converter/xml/sxw/wordsmith/WSDecoder.java
URL: http://svn.apache.org/viewvc/openoffice/branches/ia2/main/xmerge/source/wordsmith/java/org/openoffice/xmerge/converter/xml/sxw/wordsmith/WSDecoder.java?rev=1441343&r1=1441342&r2=1441343&view=diff
==============================================================================
--- openoffice/branches/ia2/main/xmerge/source/wordsmith/java/org/openoffice/xmerge/converter/xml/sxw/wordsmith/WSDecoder.java (original)
+++ openoffice/branches/ia2/main/xmerge/source/wordsmith/java/org/openoffice/xmerge/converter/xml/sxw/wordsmith/WSDecoder.java Fri Feb  1 08:46:00 2013
@@ -61,7 +61,7 @@ final class WSDecoder implements DOCCons
     /**
      *  Decode the text records into a single <code>byte</code> array.
      *
-     *  @param  Record  <code>Record</code> array holding WordSmith
+     *  @param  recs  <code>Record</code> array holding WordSmith
      *                  contents.
      *
      *  @throws  IOException  If any I/O error occurs.
@@ -118,7 +118,7 @@ final class WSDecoder implements DOCCons
     /**
      *  Decode the text records into a <code>Wse</code> array.
      *
-     *  @param  Record[]  <code>Record</code> array holding DOC
+     *  @param  recs  <code>Record</code> array holding DOC
      *                    contents.
      *
      *  @throws  IOException  If any I/O error occurs.
@@ -178,7 +178,7 @@ final class WSDecoder implements DOCCons
      *  it as a problem with the encoding of that PDB and
      *  throw <code>IOException</code>.</p>
      *
-     *  @param  bytes           Compressed <code>byte</code> array
+     *  @param  cBytes           Compressed <code>byte</code> array
      *  @param  textRecordSize  Size of uncompressed <code>byte</code>
      *                          array
      *

Modified: openoffice/branches/ia2/main/xmerge/source/xmerge/build.xml
URL: http://svn.apache.org/viewvc/openoffice/branches/ia2/main/xmerge/source/xmerge/build.xml?rev=1441343&r1=1441342&r2=1441343&view=diff
==============================================================================
--- openoffice/branches/ia2/main/xmerge/source/xmerge/build.xml (original)
+++ openoffice/branches/ia2/main/xmerge/source/xmerge/build.xml Fri Feb  1 08:46:00 2013
@@ -64,8 +64,8 @@
                          includes="**/*.properties" />
             <manifest>
                 <attribute name="Main-Class" value="org.openoffice.xmerge.test.Driver"/>
-                <attribute name="Specification-Title" value="OpenOffice XMerge Framework"/>
-                <attribute name="Specification-Vendor" value="OpenOffice.org"/>
+                <attribute name="Specification-Title" value="Apache OpenOffice XMerge Framework"/>
+                <attribute name="Specification-Vendor" value="Apache OpenOffice"/>
                 <attribute name="Specification-Version" value="0.6.0"/>
                 <attribute name="Implementation-Version" value="#IMPL-VERSION#"/>
                 <attribute name="Class-Path" value="xml-apis.jar xercesImpl.jar serializer.jar"/>

Modified: openoffice/branches/ia2/main/xmerge/source/xmerge/java/org/openoffice/xmerge/converter/dom/DOMDocument.java
URL: http://svn.apache.org/viewvc/openoffice/branches/ia2/main/xmerge/source/xmerge/java/org/openoffice/xmerge/converter/dom/DOMDocument.java?rev=1441343&r1=1441342&r2=1441343&view=diff
==============================================================================
--- openoffice/branches/ia2/main/xmerge/source/xmerge/java/org/openoffice/xmerge/converter/dom/DOMDocument.java (original)
+++ openoffice/branches/ia2/main/xmerge/source/xmerge/java/org/openoffice/xmerge/converter/dom/DOMDocument.java Fri Feb  1 08:46:00 2013
@@ -235,7 +235,7 @@ public class DOMDocument
      *  <p>TODO: remove dependency on com.sun.xml.tree.XmlDocument
      *  package!</p>
      *
-     *  @param  Document  DOM <code>Document</code> object.
+     *  @param  doc  DOM <code>Document</code> object.
      *
      *  @return  <code>byte</code> array of DOM <code>Document</code>
      *           object.
@@ -369,7 +369,7 @@ public class DOMDocument
 
     /**
      *  <p>Creates a new DOM <code>Document</code> containing minimum
-     *  OpenOffice XML tags.</p>
+     *  OpenOffice.org XML tags.</p>
      *
      *  <p>This method uses the subclass
      *  <code>getOfficeClassAttribute</code> method to get the

Modified: openoffice/branches/ia2/main/xmerge/source/xmerge/java/org/openoffice/xmerge/converter/palm/PdbHeader.java
URL: http://svn.apache.org/viewvc/openoffice/branches/ia2/main/xmerge/source/xmerge/java/org/openoffice/xmerge/converter/palm/PdbHeader.java?rev=1441343&r1=1441342&r2=1441343&view=diff
==============================================================================
--- openoffice/branches/ia2/main/xmerge/source/xmerge/java/org/openoffice/xmerge/converter/palm/PdbHeader.java (original)
+++ openoffice/branches/ia2/main/xmerge/source/xmerge/java/org/openoffice/xmerge/converter/palm/PdbHeader.java Fri Feb  1 08:46:00 2013
@@ -106,7 +106,7 @@ final class PdbHeader {
      *  Read in the data for the PDB header.  Need to
      *  preserve the unsigned value for some of the fields.
      *
-     *  @param  di  A <code>DataInput</code> object.
+     *  @param  in  A <code>DataInput</code> object.
      *
      *  @throws  IOException  If any I/O error occurs.
      */

Modified: openoffice/branches/ia2/main/xmerge/source/xmerge/java/org/openoffice/xmerge/converter/xml/EmbeddedBinaryObject.java
URL: http://svn.apache.org/viewvc/openoffice/branches/ia2/main/xmerge/source/xmerge/java/org/openoffice/xmerge/converter/xml/EmbeddedBinaryObject.java?rev=1441343&r1=1441342&r2=1441343&view=diff
==============================================================================
--- openoffice/branches/ia2/main/xmerge/source/xmerge/java/org/openoffice/xmerge/converter/xml/EmbeddedBinaryObject.java (original)
+++ openoffice/branches/ia2/main/xmerge/source/xmerge/java/org/openoffice/xmerge/converter/xml/EmbeddedBinaryObject.java Fri Feb  1 08:46:00 2013
@@ -107,8 +107,6 @@ public class EmbeddedBinaryObject extend
     /** 
      * Package private method that constructs the manifest.xml entries for this
      * embedded object.
-     *
-     * @return  Document    <code>Document</code> containing the manifest entries.
      */
     void writeManifestData(Document manifestDoc) throws DOMException {        
         Element objNode = manifestDoc.createElement(OfficeConstants.TAG_MANIFEST_FILE);

Modified: openoffice/branches/ia2/main/xmerge/source/xmerge/java/org/openoffice/xmerge/converter/xml/EmbeddedObject.java
URL: http://svn.apache.org/viewvc/openoffice/branches/ia2/main/xmerge/source/xmerge/java/org/openoffice/xmerge/converter/xml/EmbeddedObject.java?rev=1441343&r1=1441342&r2=1441343&view=diff
==============================================================================
--- openoffice/branches/ia2/main/xmerge/source/xmerge/java/org/openoffice/xmerge/converter/xml/EmbeddedObject.java (original)
+++ openoffice/branches/ia2/main/xmerge/source/xmerge/java/org/openoffice/xmerge/converter/xml/EmbeddedObject.java Fri Feb  1 08:46:00 2013
@@ -105,8 +105,6 @@ public abstract class EmbeddedObject {
     /**
      * Package private method that constructs the manifest.xml entries for this
      * embedded object.
-     *
-     * @return  Document    <code>Document</code> containing the manifest entries.
      */
     abstract void writeManifestData(Document manifestDoc) throws DOMException;
-}
\ No newline at end of file
+}

Modified: openoffice/branches/ia2/main/xmerge/source/xmerge/java/org/openoffice/xmerge/converter/xml/OfficeDocument.java
URL: http://svn.apache.org/viewvc/openoffice/branches/ia2/main/xmerge/source/xmerge/java/org/openoffice/xmerge/converter/xml/OfficeDocument.java?rev=1441343&r1=1441342&r2=1441343&view=diff
==============================================================================
--- openoffice/branches/ia2/main/xmerge/source/xmerge/java/org/openoffice/xmerge/converter/xml/OfficeDocument.java (original)
+++ openoffice/branches/ia2/main/xmerge/source/xmerge/java/org/openoffice/xmerge/converter/xml/OfficeDocument.java Fri Feb  1 08:46:00 2013
@@ -843,7 +843,7 @@ public abstract class OfficeDocument
      *  <p>TODO: remove dependency on com.sun.xml.tree.XmlDocument
      *  package!</p>
      *
-     *  @param  Document  DOM <code>Document</code> object.
+     *  @param  doc  DOM <code>Document</code> object.
      *
      *  @return  <code>byte</code> array of DOM <code>Document</code>
      *           object.
@@ -1022,7 +1022,7 @@ public abstract class OfficeDocument
 
     /**
      *  <p>Creates a new DOM <code>Document</code> containing minimum
-     *  OpenOffice XML tags.</p>
+     *  OpenOffice.org XML tags.</p>
      *
      *  <p>This method uses the subclass
      *  <code>getOfficeClassAttribute</code> method to get the
@@ -1061,7 +1061,7 @@ public abstract class OfficeDocument
 
     /**
      *  <p>Creates a new DOM <code>Document</code> containing minimum
-     *  OpenOffice XML tags.</p>
+     *  OpenOffice.org XML tags.</p>
      *
      *  <p>This method uses the subclass
      *  <code>getOfficeClassAttribute</code> method to get the

Modified: openoffice/branches/ia2/main/xmerge/source/xmerge/java/org/openoffice/xmerge/converter/xml/OfficeZip.java
URL: http://svn.apache.org/viewvc/openoffice/branches/ia2/main/xmerge/source/xmerge/java/org/openoffice/xmerge/converter/xml/OfficeZip.java?rev=1441343&r1=1441342&r2=1441343&view=diff
==============================================================================
--- openoffice/branches/ia2/main/xmerge/source/xmerge/java/org/openoffice/xmerge/converter/xml/OfficeZip.java (original)
+++ openoffice/branches/ia2/main/xmerge/source/xmerge/java/org/openoffice/xmerge/converter/xml/OfficeZip.java Fri Feb  1 08:46:00 2013
@@ -39,7 +39,7 @@ import org.openoffice.xmerge.util.Debug;
 
 /**
  *  Class used by {@link
- *  org.openoffice.xmerge.converter.OfficeDocument
+ *  org.openoffice.xmerge.converter.xml.OfficeDocument
  *  OfficeDocument} to handle reading and writing
  *  from a ZIP file, as well as storing ZIP entries.
  *

Modified: openoffice/branches/ia2/main/xmerge/source/xmerge/java/org/openoffice/xmerge/converter/xml/TextStyle.java
URL: http://svn.apache.org/viewvc/openoffice/branches/ia2/main/xmerge/source/xmerge/java/org/openoffice/xmerge/converter/xml/TextStyle.java?rev=1441343&r1=1441342&r2=1441343&view=diff
==============================================================================
--- openoffice/branches/ia2/main/xmerge/source/xmerge/java/org/openoffice/xmerge/converter/xml/TextStyle.java (original)
+++ openoffice/branches/ia2/main/xmerge/source/xmerge/java/org/openoffice/xmerge/converter/xml/TextStyle.java Fri Feb  1 08:46:00 2013
@@ -446,7 +446,7 @@ public class TextStyle extends Style imp
      *  Private function to return the value as an element in
      *  a Comma Separated Value (CSV) format.
      *
-     *  @param  The value to format.
+     *  @param  value The value to format.
      *
      *  @return  The formatted value.
      */

Modified: openoffice/branches/ia2/main/xmerge/source/xmerge/java/org/openoffice/xmerge/converter/xml/sxc/BookSettings.java
URL: http://svn.apache.org/viewvc/openoffice/branches/ia2/main/xmerge/source/xmerge/java/org/openoffice/xmerge/converter/xml/sxc/BookSettings.java?rev=1441343&r1=1441342&r2=1441343&view=diff
==============================================================================
--- openoffice/branches/ia2/main/xmerge/source/xmerge/java/org/openoffice/xmerge/converter/xml/sxc/BookSettings.java (original)
+++ openoffice/branches/ia2/main/xmerge/source/xmerge/java/org/openoffice/xmerge/converter/xml/sxc/BookSettings.java Fri Feb  1 08:46:00 2013
@@ -116,7 +116,7 @@ public class BookSettings implements Off
 	 * Adds an XML entry for a particular setting
 	 *
 	 * @param root the root node at which to add the xml entry
-	 * @param attriute the name of the attribute to add
+	 * @param attribute the name of the attribute to add
 	 * @param type the attribute type (int, short etc)
 	 * @param value the value of the attribute
 	 */

Modified: openoffice/branches/ia2/main/xmerge/source/xmerge/java/org/openoffice/xmerge/converter/xml/sxc/SheetSettings.java
URL: http://svn.apache.org/viewvc/openoffice/branches/ia2/main/xmerge/source/xmerge/java/org/openoffice/xmerge/converter/xml/sxc/SheetSettings.java?rev=1441343&r1=1441342&r2=1441343&view=diff
==============================================================================
--- openoffice/branches/ia2/main/xmerge/source/xmerge/java/org/openoffice/xmerge/converter/xml/sxc/SheetSettings.java (original)
+++ openoffice/branches/ia2/main/xmerge/source/xmerge/java/org/openoffice/xmerge/converter/xml/sxc/SheetSettings.java Fri Feb  1 08:46:00 2013
@@ -236,7 +236,7 @@ public class SheetSettings implements Of
 	 * Adds an XML entry for a particular setting
 	 *
 	 * @param root the root node at which to add the xml entry
-	 * @param attriute the name of the attribute to add
+	 * @param attribute the name of the attribute to add
 	 * @param type the attribute type (int, short etc)
 	 * @param value the value of the attribute
 	 */

Modified: openoffice/branches/ia2/main/xmerge/source/xmerge/java/org/openoffice/xmerge/util/OfficeUtil.java
URL: http://svn.apache.org/viewvc/openoffice/branches/ia2/main/xmerge/source/xmerge/java/org/openoffice/xmerge/util/OfficeUtil.java?rev=1441343&r1=1441342&r2=1441343&view=diff
==============================================================================
--- openoffice/branches/ia2/main/xmerge/source/xmerge/java/org/openoffice/xmerge/util/OfficeUtil.java (original)
+++ openoffice/branches/ia2/main/xmerge/source/xmerge/java/org/openoffice/xmerge/util/OfficeUtil.java Fri Feb  1 08:46:00 2013
@@ -43,7 +43,7 @@ public class OfficeUtil implements Offic
     
     /**
      * <p>Method to replace whitespace character within text with appropriate 
-     *    OpenOffice tags.</p>
+     *    OpenOffice.org XML tags.</p>
      *
      * @param   text      The text to parse for whitespace.
      *

Modified: openoffice/branches/ia2/main/xmerge/util/build.xml
URL: http://svn.apache.org/viewvc/openoffice/branches/ia2/main/xmerge/util/build.xml?rev=1441343&r1=1441342&r2=1441343&view=diff
==============================================================================
--- openoffice/branches/ia2/main/xmerge/util/build.xml (original)
+++ openoffice/branches/ia2/main/xmerge/util/build.xml Fri Feb  1 08:46:00 2013
@@ -53,8 +53,8 @@
 	         nodeprecated="true"
 	         nodeprecatedlist="true"
              use="true"
-             Doctitle="OpenOffice XMerge API"
-             windowtitle="OpenOffice XMerge API"
+             Doctitle="Apache OpenOffice XMerge API"
+             windowtitle="Apache OpenOffice XMerge API"
              classpathref="classpath">
             <fileset dir="../source/bridge" defaultexcludes="yes">
                <include name="**/*.java"/>

Modified: openoffice/branches/ia2/main/xmerge/util/xmerge.mf
URL: http://svn.apache.org/viewvc/openoffice/branches/ia2/main/xmerge/util/xmerge.mf?rev=1441343&r1=1441342&r2=1441343&view=diff
==============================================================================
--- openoffice/branches/ia2/main/xmerge/util/xmerge.mf (original)
+++ openoffice/branches/ia2/main/xmerge/util/xmerge.mf Fri Feb  1 08:46:00 2013
@@ -1,8 +1,8 @@
 Manifest-Version: 1.0
 Main-Class: org.openoffice.xmerge.test.Driver
 Class-Path: xml-apis.jar xercesImpl.jar serializer.jar
-Specification-Title: OpenOffice XMerge Framework
-Specification-Vendor: OpenOffice.org
+Specification-Title: Apache OpenOffice XMerge Framework
+Specification-Vendor: Apache OpenOffice
 Specification-Version: 0.6.0
 Implementation-Version: #IMPL-VERSION#
 

Modified: openoffice/branches/ia2/main/xmlhelp/source/cxxhelp/provider/makefile.mk
URL: http://svn.apache.org/viewvc/openoffice/branches/ia2/main/xmlhelp/source/cxxhelp/provider/makefile.mk?rev=1441343&r1=1441342&r2=1441343&view=diff
==============================================================================
--- openoffice/branches/ia2/main/xmlhelp/source/cxxhelp/provider/makefile.mk (original)
+++ openoffice/branches/ia2/main/xmlhelp/source/cxxhelp/provider/makefile.mk Fri Feb  1 08:46:00 2013
@@ -39,7 +39,7 @@ NO_BSYMBOLIC=TRUE
 # technique though, so this warning is plain wrong and has been fixed 
 # in gcc 4.3. Unfortunately there is no way at all to suppress this warning.
 # Some files in this directory use zero allocated arrays, we need to
-# diable the WaE mechanism for the GCC 4.2.x series.
+# disable the WaE mechanism for the GCC 4.2.x series.
 .IF "$(COM)"=="GCC"
 .IF "$(CCNUMVER)">="000400020000" && "$(CCNUMVER)"<="000400020003"
 CFLAGSWERRCXX:=

Modified: openoffice/branches/ia2/main/xmloff/dtd/office.dtd
URL: http://svn.apache.org/viewvc/openoffice/branches/ia2/main/xmloff/dtd/office.dtd?rev=1441343&r1=1441342&r2=1441343&view=diff
==============================================================================
--- openoffice/branches/ia2/main/xmloff/dtd/office.dtd (original)
+++ openoffice/branches/ia2/main/xmloff/dtd/office.dtd Fri Feb  1 08:46:00 2013
@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="UTF-8"?>
 <!--***********************************************************
- * 
+ *
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -8,19 +8,29 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  *   http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
  * KIND, either express or implied.  See the License for the
  * specific language governing permissions and limitations
  * under the License.
- * 
+ *
  ***********************************************************-->
 
+<!-- This DTD and the entities it includes are for the
+     XML document format produced by OpenOffice.org 1.x.
 
+     This DTD is for reference from the XML prolog of documents
+     in that OpenOffice.org 1.x format.  It can be used for the
+     DTD validation of those XML documents.
+
+     This DTD is not applicable to ODF documents.  ODF support
+     began in OpenOffice.org 2.x releases.  ODF XML documents
+     have Relax NG Schemas.
+     -->
 
 <!ENTITY % dtypes-mod SYSTEM "dtypes.mod">
 %dtypes-mod;

Modified: openoffice/branches/ia2/main/xmloff/source/core/xmlimp.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/ia2/main/xmloff/source/core/xmlimp.cxx?rev=1441343&r1=1441342&r2=1441343&view=diff
==============================================================================
--- openoffice/branches/ia2/main/xmloff/source/core/xmlimp.cxx (original)
+++ openoffice/branches/ia2/main/xmloff/source/core/xmlimp.cxx Fri Feb  1 08:46:00 2013
@@ -210,7 +210,7 @@ namespace
             ~DocumentInfo()
             {}        
 
-            const sal_uInt16 getGeneratorVersion() const
+            sal_uInt16 getGeneratorVersion() const
             {
                 return mnGeneratorVersion;        
             }
@@ -278,7 +278,7 @@ public:
 	}
 
     // --> ORW
-    const sal_uInt16 getGeneratorVersion( const SvXMLImport& rImport )
+    sal_uInt16 getGeneratorVersion( const SvXMLImport& rImport )
     {
         if ( !mpDocumentInfo.get() )
         {

Modified: openoffice/branches/ia2/main/xmloff/source/draw/shapeexport4.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/ia2/main/xmloff/source/draw/shapeexport4.cxx?rev=1441343&r1=1441342&r2=1441343&view=diff
==============================================================================
--- openoffice/branches/ia2/main/xmloff/source/draw/shapeexport4.cxx (original)
+++ openoffice/branches/ia2/main/xmloff/source/draw/shapeexport4.cxx Fri Feb  1 08:46:00 2013
@@ -473,7 +473,7 @@ void ImpExportEnhancedGeometry( SvXMLExp
 
 		if ( aGeoPropSet >>= aGeoPropSeq )
 		{
-			const rtl::OUString	sCustomShapeType( RTL_CONSTASCII_USTRINGPARAM( "NonPrimitive" ) );
+			const rtl::OUString	sCustomShapeType( RTL_CONSTASCII_USTRINGPARAM( "non-primitive" ) );
 			rtl::OUString aCustomShapeType( sCustomShapeType );
 
 			sal_Int32 j, nGeoPropCount = aGeoPropSeq.getLength();

Modified: openoffice/branches/ia2/main/xmloff/source/forms/formenums.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/ia2/main/xmloff/source/forms/formenums.cxx?rev=1441343&r1=1441342&r2=1441343&view=diff
==============================================================================
--- openoffice/branches/ia2/main/xmloff/source/forms/formenums.cxx (original)
+++ openoffice/branches/ia2/main/xmloff/source/forms/formenums.cxx Fri Feb  1 08:46:00 2013
@@ -320,11 +320,11 @@ namespace xmloff
                 {
                     static const SvXMLEnumMapEntry aScaleModeMap[] =
                     {
-                        { XML_BACKGROUND_NO_REPEAT, ImageScaleMode::None },
-                        { XML_REPEAT,               ImageScaleMode::None },  // repeating the image is not supported
-                        { XML_STRETCH,              ImageScaleMode::Anisotropic },
-                        { XML_SCALE,                ImageScaleMode::Isotropic },
-                        { XML_TOKEN_INVALID,        ImageScaleMode::None }
+                        { XML_BACKGROUND_NO_REPEAT, ImageScaleMode::NONE },
+                        { XML_REPEAT,               ImageScaleMode::NONE },  // repeating the image is not supported
+                        { XML_STRETCH,              ImageScaleMode::ANISOTROPIC },
+                        { XML_SCALE,                ImageScaleMode::ISOTROPIC },
+                        { XML_TOKEN_INVALID,        ImageScaleMode::NONE }
                     };
                     rReturn = aScaleModeMap;
                 }

Modified: openoffice/branches/ia2/main/xmlsecurity/source/dialogs/digitalsignaturesdialog.src
URL: http://svn.apache.org/viewvc/openoffice/branches/ia2/main/xmlsecurity/source/dialogs/digitalsignaturesdialog.src?rev=1441343&r1=1441342&r2=1441343&view=diff
==============================================================================
--- openoffice/branches/ia2/main/xmlsecurity/source/dialogs/digitalsignaturesdialog.src (original)
+++ openoffice/branches/ia2/main/xmlsecurity/source/dialogs/digitalsignaturesdialog.src Fri Feb  1 08:46:00 2013
@@ -200,7 +200,7 @@ ErrorBox RID_XMLSECDLG_OLD_ODF_FORMAT
     Buttons = WB_OK ;
     DefButton = WB_DEF_OK ;
     Message [ en-US ] = 
-		"This document contains signatures in ODF 1.1 (OpenOffice.org 2.x) format. "
+		"This document contains signatures in ODF 1.1 format. "
 		"Signing documents in %PRODUCTNAME %PRODUCTVERSION requires ODF 1.2 format version. "
 		"Thus no signatures can be added or removed to this document.\n\n"
 		"Save document in ODF 1.2 format and add all desired signatures again.";

Modified: openoffice/branches/ia2/main/xmlsecurity/source/xmlsec/nss/nssinitializer.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/ia2/main/xmlsecurity/source/xmlsec/nss/nssinitializer.cxx?rev=1441343&r1=1441342&r2=1441343&view=diff
==============================================================================
--- openoffice/branches/ia2/main/xmlsecurity/source/xmlsec/nss/nssinitializer.cxx (original)
+++ openoffice/branches/ia2/main/xmlsecurity/source/xmlsec/nss/nssinitializer.cxx Fri Feb  1 08:46:00 2013
@@ -87,7 +87,7 @@ using ::rtl::OString;
 
 #define IMPLEMENTATION_NAME "com.sun.star.xml.security.bridge.xmlsec.NSSInitializer_NssImpl"
 
-#define ROOT_CERTS "Root Certs for OpenOffice.org"
+#define ROOT_CERTS "Root Certs for Apache OpenOffice"
 
 extern "C" void nsscrypto_finalize();
 

Propchange: openoffice/branches/ia2/test/
------------------------------------------------------------------------------
  Merged /openoffice/branches/alg/clibboard/test:r1428975-1437368
  Merged /openoffice/trunk/test:r1417536-1438338

Modified: openoffice/branches/ia2/test/build.xml
URL: http://svn.apache.org/viewvc/openoffice/branches/ia2/test/build.xml?rev=1441343&r1=1441342&r2=1441343&view=diff
==============================================================================
--- openoffice/branches/ia2/test/build.xml (original)
+++ openoffice/branches/ia2/test/build.xml Fri Feb  1 08:46:00 2013
@@ -144,7 +144,7 @@
 		</condition>
 		<pathconvert property="openoffice.pack" setonempty="false">
 			<path>
-				<fileset dir="${env.SRC_ROOT}/instsetoo_native/${env.INPATH}/OpenOffice/archive/install/en-US" includes="*.tar.gz,*.zip"  erroronmissingdir="false"/>
+				<fileset dir="${env.SRC_ROOT}/instsetoo_native/${env.INPATH}/Apache_OpenOffice/archive/install/en-US" includes="*.tar.gz,*.zip"  erroronmissingdir="false"/>
 			</path>
 		</pathconvert>
 		<condition property="test.arg0" value="-Dopenoffice.pack=${openoffice.pack}">

Modified: openoffice/branches/ia2/test/testcommon/source/org/openoffice/test/Run.java
URL: http://svn.apache.org/viewvc/openoffice/branches/ia2/test/testcommon/source/org/openoffice/test/Run.java?rev=1441343&r1=1441342&r2=1441343&view=diff
==============================================================================
--- openoffice/branches/ia2/test/testcommon/source/org/openoffice/test/Run.java (original)
+++ openoffice/branches/ia2/test/testcommon/source/org/openoffice/test/Run.java Fri Feb  1 08:46:00 2013
@@ -28,6 +28,7 @@ import java.util.logging.Level;
 import org.junit.runner.JUnitCore;
 import org.junit.runner.Result;
 import org.junit.runner.notification.RunListener;
+import org.junit.runner.notification.Failure;
 import org.openoffice.test.common.FileUtil;
 import org.openoffice.test.common.Logger;
 import org.openoffice.test.common.NamedRequest;
@@ -142,10 +143,15 @@ public class Run {
 		int code = 0;
 		for (NamedRequest request : requests) {
 			Result result = core.run(request.getRunner());
-			if (!result.wasSuccessful())
+			if (!result.wasSuccessful()) {
 				code = 1;
+				java.util.List<Failure> failureList = result.getFailures();
+				for( Failure f: failureList)
+					log.log( Level.SEVERE, "Failure in "+request.getName()+" :"+ f.toString(), f.getException());
+			}
 		}
 		
 		System.exit(code);
 	}
 }
+

Modified: openoffice/branches/ia2/test/testcommon/source/org/openoffice/test/common/FileProvider.java
URL: http://svn.apache.org/viewvc/openoffice/branches/ia2/test/testcommon/source/org/openoffice/test/common/FileProvider.java?rev=1441343&r1=1441342&r2=1441343&view=diff
==============================================================================
--- openoffice/branches/ia2/test/testcommon/source/org/openoffice/test/common/FileProvider.java (original)
+++ openoffice/branches/ia2/test/testcommon/source/org/openoffice/test/common/FileProvider.java Fri Feb  1 08:46:00 2013
@@ -138,7 +138,7 @@ public class FileProvider extends Suite 
 			if (a != null) {
 				Object v = f.get(null);
 				if (v != null && !(v instanceof Integer))
-					throw new InitializationError(String.format("Field annotated FileFilter '%s' must be String.", f.getName()));
+					throw new InitializationError(String.format("Field annotated FileFilter '%s' must be Integer.", f.getName()));
 				repeat = (Integer) v;
 			}
 			

Modified: openoffice/branches/ia2/test/testcommon/source/org/openoffice/test/common/XMLReporter.java
URL: http://svn.apache.org/viewvc/openoffice/branches/ia2/test/testcommon/source/org/openoffice/test/common/XMLReporter.java?rev=1441343&r1=1441342&r2=1441343&view=diff
==============================================================================
--- openoffice/branches/ia2/test/testcommon/source/org/openoffice/test/common/XMLReporter.java (original)
+++ openoffice/branches/ia2/test/testcommon/source/org/openoffice/test/common/XMLReporter.java Fri Feb  1 08:46:00 2013
@@ -177,9 +177,10 @@ public class XMLReporter extends RunList
 			System.setProperty("info.os.name", SystemUtil.getOSName());
 			System.setProperty("info.os.version", SystemUtil.getOSVersion());
 			System.setProperty("info.os.arch", SystemUtil.getOSArch());
-			System.setProperty("info.os.arch", SystemUtil.getOSArch());
-			System.setProperty("info.ip", SystemUtil.getIPAddress());
-			System.setProperty("info.hostname", SystemUtil.getHostName());
+			String ipaddrStr = SystemUtil.getIPAddress();
+			System.setProperty("info.ip", (ipaddrStr!=null) ? ipaddrStr : "UNKNOWN");
+			String hostnameStr = SystemUtil.getHostName();
+			System.setProperty("info.hostname", (hostnameStr!=null) ? hostnameStr : "UNKNOWN");
 			Set<Entry<Object, Object>> entries = System.getProperties().entrySet();
 			for (Entry<Object, Object> e : entries) {
 				Element prop = doc.createElement("property");
@@ -198,3 +199,4 @@ public class XMLReporter extends RunList
 	}
 
 }
+

Propchange: openoffice/branches/ia2/test/testcommon/source/org/openoffice/test/vcl/
------------------------------------------------------------------------------
  Merged /openoffice/trunk/test/testcommon/source/org/openoffice/test/vcl:r1417536-1438338
  Merged /openoffice/branches/alg/clibboard/test/testcommon/source/org/openoffice/test/vcl:r1428975-1437368

Modified: openoffice/branches/ia2/test/testuno/source/fvt/uno/sd/animation/TextAnimation.java
URL: http://svn.apache.org/viewvc/openoffice/branches/ia2/test/testuno/source/fvt/uno/sd/animation/TextAnimation.java?rev=1441343&r1=1441342&r2=1441343&view=diff
==============================================================================
--- openoffice/branches/ia2/test/testuno/source/fvt/uno/sd/animation/TextAnimation.java (original)
+++ openoffice/branches/ia2/test/testuno/source/fvt/uno/sd/animation/TextAnimation.java Fri Feb  1 08:46:00 2013
@@ -197,7 +197,7 @@ public class TextAnimation {
 				XStorable.class, presentationDocument);
 		xStorable.storeToURL(FileUtil.getUrl(filePath), aStoreProperties);
 
-		return UnoRuntime.queryInterface(XComponent.class,
+		return (XComponent)UnoRuntime.queryInterface(XComponent.class,
 				unoApp.loadDocument(filePath));
 	}
 }

Modified: openoffice/branches/ia2/test/testuno/source/fvt/uno/sw/frame/FrameAnchorType.java
URL: http://svn.apache.org/viewvc/openoffice/branches/ia2/test/testuno/source/fvt/uno/sw/frame/FrameAnchorType.java?rev=1441343&r1=1441342&r2=1441343&view=diff
==============================================================================
--- openoffice/branches/ia2/test/testuno/source/fvt/uno/sw/frame/FrameAnchorType.java (original)
+++ openoffice/branches/ia2/test/testuno/source/fvt/uno/sw/frame/FrameAnchorType.java Fri Feb  1 08:46:00 2013
@@ -1,3 +1,23 @@
+/**************************************************************
+ * 
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ * 
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ * 
+ *************************************************************/
 package fvt.uno.sw.frame;
 
 import static org.junit.Assert.*;

Modified: openoffice/branches/ia2/test/testuno/source/fvt/uno/sw/frame/FrameBackColor.java
URL: http://svn.apache.org/viewvc/openoffice/branches/ia2/test/testuno/source/fvt/uno/sw/frame/FrameBackColor.java?rev=1441343&r1=1441342&r2=1441343&view=diff
==============================================================================
--- openoffice/branches/ia2/test/testuno/source/fvt/uno/sw/frame/FrameBackColor.java (original)
+++ openoffice/branches/ia2/test/testuno/source/fvt/uno/sw/frame/FrameBackColor.java Fri Feb  1 08:46:00 2013
@@ -1,3 +1,23 @@
+/**************************************************************
+ * 
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ * 
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ * 
+ *************************************************************/
 package fvt.uno.sw.frame;
 
 import static org.junit.Assert.*;

Modified: openoffice/branches/ia2/test/testuno/source/fvt/uno/sw/frame/FrameBackGraphic.java
URL: http://svn.apache.org/viewvc/openoffice/branches/ia2/test/testuno/source/fvt/uno/sw/frame/FrameBackGraphic.java?rev=1441343&r1=1441342&r2=1441343&view=diff
==============================================================================
--- openoffice/branches/ia2/test/testuno/source/fvt/uno/sw/frame/FrameBackGraphic.java (original)
+++ openoffice/branches/ia2/test/testuno/source/fvt/uno/sw/frame/FrameBackGraphic.java Fri Feb  1 08:46:00 2013
@@ -1,3 +1,23 @@
+/**************************************************************
+ * 
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ * 
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ * 
+ *************************************************************/
 package fvt.uno.sw.frame;
 
 import static org.junit.Assert.*;

Modified: openoffice/branches/ia2/test/testuno/source/fvt/uno/sw/frame/FrameBorder.java
URL: http://svn.apache.org/viewvc/openoffice/branches/ia2/test/testuno/source/fvt/uno/sw/frame/FrameBorder.java?rev=1441343&r1=1441342&r2=1441343&view=diff
==============================================================================
--- openoffice/branches/ia2/test/testuno/source/fvt/uno/sw/frame/FrameBorder.java (original)
+++ openoffice/branches/ia2/test/testuno/source/fvt/uno/sw/frame/FrameBorder.java Fri Feb  1 08:46:00 2013
@@ -1,3 +1,23 @@
+/**************************************************************
+ * 
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ * 
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ * 
+ *************************************************************/
 package fvt.uno.sw.frame;
 
 import static org.junit.Assert.*;

Modified: openoffice/branches/ia2/test/testuno/source/fvt/uno/sw/frame/FrameBorderSpacingtoContent.java
URL: http://svn.apache.org/viewvc/openoffice/branches/ia2/test/testuno/source/fvt/uno/sw/frame/FrameBorderSpacingtoContent.java?rev=1441343&r1=1441342&r2=1441343&view=diff
==============================================================================
--- openoffice/branches/ia2/test/testuno/source/fvt/uno/sw/frame/FrameBorderSpacingtoContent.java (original)
+++ openoffice/branches/ia2/test/testuno/source/fvt/uno/sw/frame/FrameBorderSpacingtoContent.java Fri Feb  1 08:46:00 2013
@@ -1,3 +1,23 @@
+/**************************************************************
+ * 
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ * 
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ * 
+ *************************************************************/
 package fvt.uno.sw.frame;
 
 import static org.junit.Assert.*;

Modified: openoffice/branches/ia2/test/testuno/source/fvt/uno/sw/frame/FrameDescription.java
URL: http://svn.apache.org/viewvc/openoffice/branches/ia2/test/testuno/source/fvt/uno/sw/frame/FrameDescription.java?rev=1441343&r1=1441342&r2=1441343&view=diff
==============================================================================
--- openoffice/branches/ia2/test/testuno/source/fvt/uno/sw/frame/FrameDescription.java (original)
+++ openoffice/branches/ia2/test/testuno/source/fvt/uno/sw/frame/FrameDescription.java Fri Feb  1 08:46:00 2013
@@ -1,3 +1,23 @@
+/**************************************************************
+ * 
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ * 
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ * 
+ *************************************************************/
 package fvt.uno.sw.frame;
 
 import static org.junit.Assert.*;

Modified: openoffice/branches/ia2/test/testuno/source/fvt/uno/sw/frame/FrameHyperlink.java
URL: http://svn.apache.org/viewvc/openoffice/branches/ia2/test/testuno/source/fvt/uno/sw/frame/FrameHyperlink.java?rev=1441343&r1=1441342&r2=1441343&view=diff
==============================================================================
--- openoffice/branches/ia2/test/testuno/source/fvt/uno/sw/frame/FrameHyperlink.java (original)
+++ openoffice/branches/ia2/test/testuno/source/fvt/uno/sw/frame/FrameHyperlink.java Fri Feb  1 08:46:00 2013
@@ -1,3 +1,23 @@
+/**************************************************************
+ * 
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ * 
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ * 
+ *************************************************************/
 package fvt.uno.sw.frame;
 
 import static org.junit.Assert.*;

Modified: openoffice/branches/ia2/test/testuno/source/fvt/uno/sw/frame/FramePosition.java
URL: http://svn.apache.org/viewvc/openoffice/branches/ia2/test/testuno/source/fvt/uno/sw/frame/FramePosition.java?rev=1441343&r1=1441342&r2=1441343&view=diff
==============================================================================
--- openoffice/branches/ia2/test/testuno/source/fvt/uno/sw/frame/FramePosition.java (original)
+++ openoffice/branches/ia2/test/testuno/source/fvt/uno/sw/frame/FramePosition.java Fri Feb  1 08:46:00 2013
@@ -1,3 +1,23 @@
+/**************************************************************
+ * 
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ * 
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ * 
+ *************************************************************/
 package fvt.uno.sw.frame;
 
 import static org.junit.Assert.*;

Modified: openoffice/branches/ia2/test/testuno/source/fvt/uno/sw/frame/FrameShadow.java
URL: http://svn.apache.org/viewvc/openoffice/branches/ia2/test/testuno/source/fvt/uno/sw/frame/FrameShadow.java?rev=1441343&r1=1441342&r2=1441343&view=diff
==============================================================================
--- openoffice/branches/ia2/test/testuno/source/fvt/uno/sw/frame/FrameShadow.java (original)
+++ openoffice/branches/ia2/test/testuno/source/fvt/uno/sw/frame/FrameShadow.java Fri Feb  1 08:46:00 2013
@@ -1,3 +1,23 @@
+/**************************************************************
+ * 
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ * 
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ * 
+ *************************************************************/
 package fvt.uno.sw.frame;
 
 import static org.junit.Assert.*;

Modified: openoffice/branches/ia2/test/testuno/source/fvt/uno/sw/frame/FrameSize.java
URL: http://svn.apache.org/viewvc/openoffice/branches/ia2/test/testuno/source/fvt/uno/sw/frame/FrameSize.java?rev=1441343&r1=1441342&r2=1441343&view=diff
==============================================================================
--- openoffice/branches/ia2/test/testuno/source/fvt/uno/sw/frame/FrameSize.java (original)
+++ openoffice/branches/ia2/test/testuno/source/fvt/uno/sw/frame/FrameSize.java Fri Feb  1 08:46:00 2013
@@ -1,3 +1,23 @@
+/**************************************************************
+ * 
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ * 
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ * 
+ *************************************************************/
 package fvt.uno.sw.frame;
 
 import static org.junit.Assert.*;

Modified: openoffice/branches/ia2/test/testuno/source/fvt/uno/sw/frame/FrameWrapType.java
URL: http://svn.apache.org/viewvc/openoffice/branches/ia2/test/testuno/source/fvt/uno/sw/frame/FrameWrapType.java?rev=1441343&r1=1441342&r2=1441343&view=diff
==============================================================================
--- openoffice/branches/ia2/test/testuno/source/fvt/uno/sw/frame/FrameWrapType.java (original)
+++ openoffice/branches/ia2/test/testuno/source/fvt/uno/sw/frame/FrameWrapType.java Fri Feb  1 08:46:00 2013
@@ -1,3 +1,23 @@
+/**************************************************************
+ * 
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ * 
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ * 
+ *************************************************************/
 package fvt.uno.sw.frame;
 
 import static org.junit.Assert.*;

Modified: openoffice/branches/ia2/test/testuno/source/fvt/uno/sw/frame/InsertFrame.java
URL: http://svn.apache.org/viewvc/openoffice/branches/ia2/test/testuno/source/fvt/uno/sw/frame/InsertFrame.java?rev=1441343&r1=1441342&r2=1441343&view=diff
==============================================================================
--- openoffice/branches/ia2/test/testuno/source/fvt/uno/sw/frame/InsertFrame.java (original)
+++ openoffice/branches/ia2/test/testuno/source/fvt/uno/sw/frame/InsertFrame.java Fri Feb  1 08:46:00 2013
@@ -1,3 +1,23 @@
+/**************************************************************
+ * 
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ * 
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ * 
+ *************************************************************/
 package fvt.uno.sw.frame;
 
 import static org.junit.Assert.*;

Modified: openoffice/branches/ia2/test/testuno/source/pvt/uno/Conversion.java
URL: http://svn.apache.org/viewvc/openoffice/branches/ia2/test/testuno/source/pvt/uno/Conversion.java?rev=1441343&r1=1441342&r2=1441343&view=diff
==============================================================================
--- openoffice/branches/ia2/test/testuno/source/pvt/uno/Conversion.java (original)
+++ openoffice/branches/ia2/test/testuno/source/pvt/uno/Conversion.java Fri Feb  1 08:46:00 2013
@@ -77,7 +77,7 @@ public class Conversion {
 	
 	public static int nLevelInfo = Integer.parseInt(System.getProperty("conversion.limitationcheck", "0"));	// Level info: starts from 1, 0 means no need for limitation check
 
-	public static long nSleep = Long.parseLong(System.getProperty("conversion.sleep", "0"));	// Sleep before loadComponentFromURL and storeToURL
+	public static long nSleep = Long.parseLong(System.getProperty("conversion.sleep", "0"));	// Sleep before loadComponentFromURL and storeToURL, millisecond
 	
 	private static OpenOffice aoo = new OpenOffice();
 	
@@ -90,7 +90,7 @@ public class Conversion {
 	@BeforeClass
 	public static void beforeClass() throws Exception {
 		aoo.setUnoUrl(OpenOffice.DEFAULT_UNO_URL);
-		aoo.addArgs("-invisible", "-conversionmode", "-hidemenu", "-nofirststartwizard", "-headless");
+		aoo.addArgs("-invisible", "-conversionmode", "-hidemenu", "-nofirststartwizard", "-headless", "-enableautomation");
 	    app = new UnoApp(aoo);
 	    Testspace.prepareDataFile("limit_cfg.ini", aoo.getHome().toString()+"/program");	// Move limitation check file to installation dir
 		result = new DataSheet(getFile("output/" + Conversion.class.getName()+ ".xml"));
@@ -159,7 +159,7 @@ public class Conversion {
 	}
 
 	
-	@Test(timeout=5 * 60000)
+	@Test(timeout=10 * 60000)
 	public void testConversion() throws Exception {
 		try {
 			if (nSleep > 0)
@@ -185,12 +185,18 @@ public class Conversion {
 			closeTime = System.currentTimeMillis() - start - nSleep;
 		} catch (com.sun.star.task.ErrorCodeIOException e){
 			int errCode = e.ErrCode;
-			if( 296 == errCode ) {
+			if( 296 == errCode ) {	// limitation check file
 				loadTime = -2;
 				saveTime = -2;
 				closeTime = -2;
 			}
 			
+			if( 3878 == errCode ) {	// file is corrupt
+				loadTime = -3;
+				saveTime = -3;
+				closeTime = -3;
+			}
+			
 			throw e;
 		}
 	}
--- openoffice/branches/ia2/main/xmerge/source/pocketword/java/org/openoffice/xmerge/converter/xml/sxw/pocketword/DocumentDeserializerImpl.java (original)
+++ openoffice/branches/ia2/main/xmerge/source/pocketword/java/org/openoffice/xmerge/converter/xml/sxw/pocketword/DocumentDeserializerImpl.java Fri Feb  1 08:46:00 2013
@@ -53,7 +53,7 @@ import org.w3c.dom.Element;
  * org.openoffice.xmerge.converter.xml.sxw.pocketword.PluginFactoryImpl
  * PluginFactoryImpl}.</p>
  *
  * <p>This converts a Pocket Word file to an OpenOffice Writer XML DOM.</p>
  *
  * @author  Mark Murnane
  * @version 1.1
@@ -94,7 +94,7 @@ public final class DocumentDeserializerI
     
     /**
      *  <p>Convert the data passed into the <code>DocumentDeserializer</code>
      *  constructor into the OpenOffice Writer <code>Document</code>
      *  format.</p>
      *
      *  <p>This method may or may not be thread-safe.  It is expected
@@ -120,7 +120,7 @@ public final class DocumentDeserializerI
         }
         catch (Exception e) {
             e.printStackTrace();
-            throw new ConvertException("Error building OpenOffice Writer DOM: "
+            throw new ConvertException("Error building OpenOffice.org XML Writer DOM: "
                                         + e.toString());
             
         }
@@ -134,8 +134,6 @@ public final class DocumentDeserializerI
      *
      * @param   data    An Enumeration of all Paragraphs in the Pocket Word doc.
      *
-     * @return  The OpenOffice Writer XML representation of the data.
-     *
      * @throws  IOException     If any I/O errors occur.
      */
     private void buildDocument(Enumeration data) throws IOException {
@@ -53,7 +53,7 @@ import org.w3c.dom.Element;
  * PluginFactoryImpl}.</p>
  *
- * <p>This converts a Pocket Word file to an OpenOffice Writer XML DOM.</p>
+ * <p>This converts a Pocket Word file to an OpenOffice.org XML Writer DOM.</p>
  *
  * @author  Mark Murnane
@@ -94,7 +94,7 @@ public final class DocumentDeserializerI
     /**
      *  <p>Convert the data passed into the <code>DocumentDeserializer</code>
-     *  constructor into the OpenOffice Writer <code>Document</code>
+     *  constructor into the OpenOffice.org XML Writer <code>Document</code>
      *  format.</p>
      *

Modified: openoffice/branches/ia2/main/xmerge/source/pocketword/java/org/openoffice/xmerge/converter/xml/sxw/pocketword/DocumentSerializerImpl.java
URL: http://svn.apache.org/viewvc/openoffice/branches/ia2/main/xmerge/source/pocketword/java/org/openoffice/xmerge/converter/xml/sxw/pocketword/DocumentSerializerImpl.java?rev=1441343&r1=1441342&r2=1441343&view=diff
==============================================================================